@@ -2,12 +2,9 @@
 
 import unittest
 import os
-import sys
-# Insert .. at the beginning of path so we use this version instead
-# of something that's already been installed
-sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
 from test import _common
 
+
 class GetArtistTest(unittest.TestCase):
     def setUp(self):
         self.datadir = os.path.join(os.path.dirname(__file__), "data", "artist")
@@ -29,4 +26,8 @@ class GetArtistTest(unittest.TestCase):
 
         res = _common.open_and_parse_test_data(self.datadir, "2736bad5-6280-4c8f-92c8-27a5e63bbab2-aliases.xml")
         self.assertFalse("alias-list" in res["artist"])
-
+    
+    def testArtistTargets(self):
+        res = _common.open_and_parse_test_data(self.datadir, "b3785a55-2cf6-497d-b8e3-cfa21a36f997-artist-rels.xml")
+        self.assertTrue('target-credit' in res['artist']['artist-relation-list'][0])
+        self.assertEqual(res['artist']['artist-relation-list'][0]["target-credit"], "TAO")
