@@ -2,12 +2,9 @@
 
 import unittest
 import os
-import sys
-# Insert .. at the beginning of path so we use this version instead
-# of something that's already been installed
-sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
 from test import _common
 
+
 class GetLabelTest(unittest.TestCase):
     def setUp(self):
         self.datadir = os.path.join(os.path.dirname(__file__), "data", "label")
