@@ -1,13 +1,25 @@
 import unittest
-import os
-import sys
-sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
-
 import musicbrainzngs
 from musicbrainzngs import musicbrainz
 from test import _common
 
+
 class SubmitTest(unittest.TestCase):
+
+    def setUp(self):
+        self.orig_opener = musicbrainzngs.compat.build_opener
+        musicbrainz.set_useragent("test_client", "1.0")
+        musicbrainz.auth("user", "password")
+        musicbrainz.set_rate_limit(False)
+
+    def tearDown(self):
+        musicbrainzngs.compat.build_opener = self.orig_opener
+        musicbrainz._useragent = ""
+        musicbrainz._client = ""
+        musicbrainz.user = ""
+        musicbrainz.password = ""
+        musicbrainz.set_rate_limit(True)
+
     def test_submit_tags(self):
         self.opener = _common.FakeOpener("<response/>")
         musicbrainzngs.compat.build_opener = lambda *args: self.opener
